<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed, reactive } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
const product = computed(() => page.props.product || []);
const relatedProducts = computed(() => page.props.relatedProducts || []);
console.log(page);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');
const quantities = reactive({});

const form = useForm({});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();

    product.value.forEach(product => {
        quantities[product.id] = 1; // Default quantity
    });
});

const singleProduct = (item_number) => {
    window.location.href = `/product/${item_number}`;
};

const addToCart = (product) => {
    const productID = product.id;
    const quantity = quantities[productID];

    if(!isNaN(+quantity) && quantity !== '') {
        form.post(route('cart.add', {
            product_id: productID,
            quantity: quantity,
        }), {
            onSuccess: () => {
                flashMessage.value = "Product added to cart!";
                setTimeout(() => {
                    window.location.reload();
                }, 1000);
            },
            onError: (error) => {
                console.error(error);
            }
        });
    }
    else {
        flashMessage.value = "Quantity should be numeric";
    }
};
</script>

<template>
    <Head title="Products" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Products</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg sticky-top top-10">
                        <ProductFilter></ProductFilter>
                    </div>
                </div>
                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="windshield-image sm:rounded-lg overflow-hidden">
                        <img src="/assets/images/fixman-glass-single-product.png" alt="fixman auto glass Details">
                    </div>
                    <div class="content-box sm:rounded-lg mt-4">
                        <div v-if="loading">Loading...</div>
                        <table v-else-if="product && product.length" class="table table-striped lg:mb-6">
                            <tbody>
                                <tr>
                                    <th>Item #</th>
                                    <td>{{ product[0].item_number }}</td>
                                </tr>
                                <tr>
                                    <th>Nags Description</th>
                                    <td>{{ product[0].nags_description }}</td>
                                </tr>
                                <tr>
                                    <th>IGD GP Description</th>
                                    <td>{{ product[0].item_description }}</td>
                                </tr>
                                <tr>
                                    <th>Stock</th>
                                    <td :class="product[0].stock == 1 ? 'text-success' : 'text-danger'">
                                        {{ product[0].stock == 1 ? "In Stock" : "Please Call" }}
                                    </td>
                                </tr>
                                <tr>
                                    <th>Your Price</th>
                                    <td>${{ product[0].price }}</td>
                                </tr>
                                <tr v-if="product[0].stock == 1">
                                    <td>
                                        <input v-model.number="quantities[product[0].id]" type="text" :name="`quantity_${product[0].id}`" id="cart_qty" min="1" style="width:70px;" />
                                        <button class="cart_qty btn" @click="addToCart(product[0])">Add to cart</button>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <p v-else>No products found.</p>
                    </div>
                    <div class="content-box sm:rounded-lg mt-4">
                        <div class="col-sm-12 max-w-7xl p-0 lg:mt-6">
                            <h3 class="text-lg font-bold my-4">Related Products</h3>
                            <table v-if="relatedProducts && relatedProducts.length" class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>Item Number</th>
                                        <th v-if="!isMobile">Catalog Desc</th>
                                        <th>Price</th>
                                        <th>Stock</th>
                                        <th>Quantity</th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr v-for="product in relatedProducts" :key="product.id">
                                        <td><a href="#" @click="singleProduct(product.item_number)">{{ product.item_number }}</a></td>
                                        <td v-if="!isMobile" >{{ product.item_description }}</td>
                                        <td>{{ product.price }}</td>
                                        <td :class="product.stock == 1 ? 'text-success' : 'text-danger'">{{ product.stock == 1 ? "In Stock" : "Please Call" }}</td>
                                        <td class="cart_qty"><input v-if="product.stock == 1" v-model.number="quantities[product.id]" type="text" :name="`quantity_${product.id}`" id="cart_qty" min="1" /></td>
                                        <td><button v-if="product.stock == 1" @click="addToCart(product)">Add to cart</button></td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
.windshield-image{
    background: var(--primary);
    text-align: center;
    padding: 40px;
}
</style>
